import React from "react";

export const VisaOption = ({
	id,
	title,
	stayPeriod,
	validity,
	processingTime,
	price,
	isExpress,
	isPopular,
	onSelect,
	selected,
}: {
	id: number;
	title: string;
	stayPeriod: string;
	validity: string;
	processingTime: string;
	price: string;
	isExpress: boolean;
	isPopular: boolean;
	onSelect: (id: number) => void;
	selected: boolean;
}) => {
	return (
		<button
			onClick={() => onSelect(id)}
			className={`border rounded-lg p-4 mb-4 relative hover:border-emerald-300 ${selected ? "border-emerald-500 bg-emerald-50/[0.5]" : "border-gray-300"}`}
		>
			<div className="">
				<div className="flex justify-between items-center mb-2">
					<h3 className="font-semibold text-lg pt-2">{title}</h3>
					<div className="flex items-center">
						<span className="text-blue-600 pt-2 mr-2">E-Visa</span>
						<span className="font-bold pt-2">Tk {price}</span>
					</div>
				</div>
				<div className="text-sm flex flex-col items-start text-gray-600">
					<span className="mr-4">Stay Period: {stayPeriod}</span>
					<span className="mr-4">Validity: {validity}</span>
					<span>Processing Time: {processingTime}</span>
				</div>
				{isExpress && (
					<img
						src="/express-icon.png"
						alt="Express"
						className="w-6 h-6 absolute top-4 right-20"
					/>
				)}
				{isPopular && (
					<span className="absolute -top-1 right-4 bg-yellow-400 text-black font-semibold text-[8px] px-2 py-1 rounded-lg">
						POPULAR
					</span>
				)}
			</div>
		</button>
	);
};

export default VisaOption;
